@@ -1,10 +1,8 @@
 # ---------------------------------------------------------------------------------
 # Name:        elements.py
 
-import importlib
 # Author:      Milan Ranisavljevic
 # ---------------------------------------------------------------------------------
-import os
 import traceback
 
 from selenium.common.exceptions import NoSuchElementException, StaleElementReferenceException
@@ -295,34 +293,3 @@ class TableElement(ScreenElement):
         """
         self._refresh(obj)
         return [self._table_entry_cls(table_row) for table_row in self.driver]
-
-
-@aspect.log
-class Locators(object):
-
-    def __get__(self, obj, owner):
-        """Gets the page locators"""
-        module_name = obj.__module__.split('.')[-1]
-        clazz = getattr(importlib.import_module(f'consts.lensapps.locators.{module_name}_locators'),
-                        f'{owner.__name__}Locators')
-        return clazz(obj.driver.capabilities.get("platformName").lower())
-
-
-@aspect.log
-class AllLocators(object):
-    def __get__(self, obj, owner):
-        """Gets the page locators"""
-        lista_locatora = []
-        with os.scandir(
-                r'C:\Users\milan.ranisavljevic\PycharmProjects\test-automation-vdi\consts\lensapps\locators') as entries:
-            for entry in entries:
-                module = (entry.name)[:-3]
-                classname = ''.join(list(map(lambda word: word.capitalize(), module.split('_'))))
-                print(classname)
-                if ('EulaPopupLocators' == classname or classname == 'Init' or module == '__pycach'):
-                    continue
-                print(len(lista_locatora))
-                print(lista_locatora)
-                locator_class = getattr(importlib.import_module(f'consts.lensapps.locators.{module}'), f'{classname}')
-                lista_locatora.append(locator_class(obj.driver.capabilities.get("platformName").lower()))
-        return lista_locatora
